import { defineComponent } from "vue";
import { any, array } from "vue-types";

import { MatController } from "@/controller/MatController";
import { List } from "@queenjs/ui";
import PanelCard from "../components/PanelCard";
import PanelGroup from "../components/PanelGroup";
import MatItem from "./MatItem";

export default defineComponent({
  props: {
    sourceData: array<any>().isRequired,
    controller: any<MatController>().isRequired,
  },
  setup(props) {
    return () => {
      const { controller, sourceData } = props;

      return (
        <PanelCard title="部件库" onSave={controller.saveMatch}>
          {sourceData.map((matsGroup: MatsMatchComp, index: number) => {
            const isGroupActive = controller.isGroupActive(matsGroup);

            return (
              <PanelGroup
                key={index}
                class="cursor-pointer"
                type="asset3d.mat"
                title={matsGroup.cusName || matsGroup.name}
                tools={["rename", "lock", "clear"]}
                target={matsGroup}
                active={isGroupActive}
                onAction={(key) =>
                  controller.changeMatGroupIndex(key, matsGroup)
                }
                onClick={() => controller.switchGroup(matsGroup)}
              >
                <List data={matsGroup.matIds || []} columns={5} gap="5px">
                  {{
                    item: (matId: string, index: number) => {
                      const currentMats = controller.findMatById(matId);
                      return (
                        <MatItem
                          key={matId}
                          mat={currentMats}
                          active={index == matsGroup.index}
                          onClick={() =>
                            controller.switchGroupMatIndex(matsGroup, index)
                          }
                          // onAction={(key: string) => {
                          //   switch (key) {
                          //     case "delete":
                          //       match.actions.deleteGroupMat(matsGroup, index);
                          //       break;
                          //     case "rename":
                          //       match.actions.renameGroupMat(currentMats);
                          //       break;
                          //   }
                          // }}
                        />
                      );
                    },
                    empty: () => (
                      <div class="my-30px text-12px text-center text-gray-500">
                        暂无数据
                      </div>
                    ),
                  }}
                </List>
              </PanelGroup>
            );
          })}
          <div class="mt-20px text-12px text-center text-gray-400">
            没有更多了
          </div>
        </PanelCard>
      );
    };
  },
});
