import { MatController } from "@/controller/MatController";
import { MatchModule } from "@/modules/match";
import { QueditorModule } from "@queenjs-modules/queditor";
import { switchSceneProdComp } from "@queenjs-modules/queditor/module/controls/Queen3dCtrl/actions/geom";
import { PackMat } from "@queenjs-modules/queditor/objects";

export default function createController(
  match: MatchModule,
  queditor: QueditorModule
) {
  const ctrl = new MatController();

  const switchComp = (compName = "") => {
    switchSceneProdComp.call(
      queditor.controls.queen3dCtrl,
      queditor.store.pack.scenes[0].products[0].id,
      compName
    );
  };

  function findCompDef(product: any, compName = "") {
    return product.components.find((c: any) => c.name == compName);
  }

  function renderGroupMat(matsGroup: MatsMatchComp, isCreate = true) {
    const targetPro = queditor.helper.findProductDef(matsGroup.productId);
    if (!targetPro) return;
    const targetCom = findCompDef(targetPro, matsGroup.name);
    if (!targetCom) return;

    const mat = queditor.helper.findMatDef(matsGroup.matIds[matsGroup.index]);
    if (!mat) return;
    queditor.actions.updatePackProductCompMat(targetCom, mat, isCreate);
  }

  function clearCompMat(matsGroup: MatsMatchComp) {
    const targetPro = queditor.helper.findProductDef(matsGroup.productId);
    if (!targetPro) return;
    const targetCom = findCompDef(targetPro, matsGroup.name);
    if (!targetCom) return;
    queditor.actions.updatePackProductCompMat(targetCom, PackMat.create());
  }

  ctrl.changeMatGroupIndex = (key: string, matsGroup: MatsMatchComp) => {
    switch (key) {
      case "rename":
        match.actions.renameMatGroup(matsGroup);
        break;
      case "lock":
        match.actions.lockMatGroup();
        break;
      case "clear":
        match.actions.clearMatGroup(matsGroup);
        // removePackMat? 是否删除面料列表数据
        switchComp(matsGroup.name);
        clearCompMat(matsGroup);
        break;
    }
  };

  ctrl.switchGroupMatIndex = (matsGroup: any, index: number) => {
    matsGroup.index = index;
    renderGroupMat(matsGroup, false);
  };

  ctrl.saveMatch = () => {
    match.store.designDetail.scenePack.source = queditor.store.pack;
    match.actions.saveDesign();
  };

  ctrl.findMatById = (matId: string) => {
    const mats = queditor.store.pack.mats;
    return mats?.find((element) => element.id == matId);
  };

  ctrl.findProductById = (productId: string) => {
    const products = queditor.store.pack.products;
    return products?.find((element) => element.id == productId);
  };

  ctrl.isGroupActive = (matsGroup: MatsMatchComp) => {
    return queditor.store.currActiveProdComp?.name == matsGroup.name;
  };

  ctrl.switchGroup = (matsGroup: MatsMatchComp) => {
    switchComp(matsGroup.name || "");
  };

  // queditor.controls.drager.on(
  //   "drop:selfDrop",
  //   async (event: DragEvent, { type, data }: any, extraData: any) => {
  //     const dropData = await data();
  //     // console.error("dropData: ", dropData);
  //     if (type == "asset3d.mat") {
  //       dropMat(dropData, extraData);
  //     } else if (type == "asset3d.mesh") {
  //       dropMesh(dropData, extraData);
  //     }
  //   }
  // );

  // function dropMesh(dropData: any, target: any) {
  //   console.log("dropData: ", dropData, target);
  //   //
  // }

  // // 拖拽面料
  // function dropMat(mat: IMaterial, extraData: any) {
  //   const currGroup = findmatsGroup(extraData);
  //   if (!currGroup.matIds) currGroup.matIds = [];

  //   // TODO 判断重复拖拽
  //   if (currGroup.matIds.includes(mat.id)) {
  //     queenApi.messageError("不能重复添加色卡");
  //     return;
  //   }
  //   // update
  //   const targetPro = queditor.store.pack.products.find(
  //     (p) => p.id == extraData.productId
  //   );
  //   const targetCom = targetPro?.components.find(
  //     (c) => c.name == extraData.name
  //   );
  //   if (!targetCom) return;
  //   queditor.actions.updatePackProductCompMat(targetCom, mat, true);
  //   currGroup.matIds.push(mat.id);
  //   currGroup.index = currGroup.matIds.length - 1;
  // }

  // function findmatsGroup(target: MatsMatchComp) {
  //   const currGroup = match.store.menuOptions.sourceData.mat.find(
  //     (r: MatsMatchComp) =>
  //       r.name == target.name && r.productId == target.productId
  //   );
  //   return currGroup;
  // }

  return ctrl;
}
